@@ -350,10 +350,18 @@ def download_dir(
         files = response.json().get("files")
         for file in files:
             download_url = file.get("Url")
+            token = str(file.get("Token"))
+            parts = token.split("/")
+            # Remove the first 3 parts and join the remaining parts back into a string
+            remaining_parts = parts[
+                3:
+            ]  # This will slice the list to skip the first 3 elements
+            # Join the remaining parts with "/" to form the final string
+            filepath_in_dataset = "/".join(remaining_parts)
             _download_single_file(
                 download_url,
                 id,
-                file.get("Name") + file.get("Ext"),
+                filepath_in_dataset,
                 cache_dir,
                 local_dir,
             )
